/*
 * Copyright (c) 2013 CNRS/LAAS
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <stdio.h>
#include <stdlib.h>

#include <rmp440/rmp440.h>

struct rmp440_config *
readConfig(char *device)
{
	struct rmp440_feedback *fb;
	struct rmp440_io *rmp = NULL;
	struct rmp440_config *cfg;

	fb = rmp440FeedbackInit(NULL);
	if (fb == NULL)
		return NULL;
	cfg = (struct rmp440_config *)malloc(sizeof(struct rmp440_config));
	if (cfg == NULL) {
		free(fb);
		return NULL;
	}
	if (device == NULL)
		rmp = rmp440Init(RMP440_INTERFACE_ETHERNET,
		    "192.168.0.40:8080");
	else {
		if (device[0] == '/') /* /dev/ttyACM0 */
			rmp = rmp440Init(RMP440_INTERFACE_USB, device);
		else if (device[0] >= '0' && device[0] <= '9')
			/* ip address */
			rmp = rmp440Init(RMP440_INTERFACE_ETHERNET,
			    device);
	}
	if (rmp == NULL) {
		fprintf(stderr, "Cannot init rmp connection\n");
		free(fb);
		free(cfg);
		return NULL;
	}
	/* send a null command and decode feedback frame */
	rmp440CmdNone(rmp);
	if (rmp440ReceiveAndDecode(rmp, fb) < 0) {
		free(fb);
		free(cfg);
		return NULL;
	}
	
	rmp440ConfigFromFeedback(cfg, fb, rmp);
	
	return cfg;
}

int
main(int argc, char *argv[])
{
	struct rmp440_config *cfg;

	// cfg = rmp440ParseConfigFile(argv[1]);
	cfg = readConfig(argv[1]);
	if (cfg == NULL) {
		printf("Could not get configuration\n");
		exit(2);
	}
	rmp440PrintConfig(cfg, stdout);
	return 0;
}
